@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2016-08-24'; # DATE
-our $VERSION = '0.48'; # VERSION
+our $DATE = '2016-09-27'; # DATE
+our $VERSION = '0.49'; # VERSION
 
 use 5.010001;
 use strict;
@@ -471,16 +471,16 @@ $SPEC{combine_answers} = {
 
 This function is useful if you want to provide a completion answer that is
 gathered from multiple sources. For example, say you are providing completion
-for the Perl tool `cpanm`, which accepts a filename (a tarball like `*.tar.gz`),
-a directory, or a module name. You can do something like this:
+for the Perl tool <prog:cpanm>, which accepts a filename (a tarball like
+`*.tar.gz`), a directory, or a module name. You can do something like this:
 
     combine_answers(
-        complete_file(word=>$word, ci=>1),
-        complete_module(word=>$word, ci=>1),
+        complete_file(word=>$word),
+        complete_module(word=>$word),
     );
 
-If a completion answer has a metadata `final` set to true, then that answer is
-used as the final answer without any combining with the other answers.
+But if a completion answer has a metadata `final` set to true, then that answer
+is used as the final answer without any combining with the other answers.
 
 _
     args => {
@@ -588,7 +588,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.48 of Complete::Util (from Perl distribution Complete-Util), released on 2016-08-24.
+This document describes version 0.49 of Complete::Util (from Perl distribution Complete-Util), released on 2016-09-27.
 
 =head1 DESCRIPTION
 
@@ -621,16 +621,16 @@ Given two or more answers, combine them into one.
 
 This function is useful if you want to provide a completion answer that is
 gathered from multiple sources. For example, say you are providing completion
-for the Perl tool C<cpanm>, which accepts a filename (a tarball like C<*.tar.gz>),
-a directory, or a module name. You can do something like this:
+for the Perl tool L<cpanm>, which accepts a filename (a tarball like
+C<*.tar.gz>), a directory, or a module name. You can do something like this:
 
  combine_answers(
-     complete_file(word=>$word, ci=>1),
-     complete_module(word=>$word, ci=>1),
+     complete_file(word=>$word),
+     complete_module(word=>$word),
  );
 
-If a completion answer has a metadata C<final> set to true, then that answer is
-used as the final answer without any combining with the other answers.
+But if a completion answer has a metadata C<final> set to true, then that answer
+is used as the final answer without any combining with the other answers.
 
 This function is not exported by default, but exportable.
 
